Provides readonly access to array data.
- Implemented types
- Implementers
- Available extensions
Properties
- first → Object?
-
The first element.
no setterinherited
- firstOrNull → T?
-
Available on Iterable<
The first element of this iterator, orT> , provided by the IterableExtensions extensionnullif the iterable is empty.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
indexed
→ Iterable<
(int, T)> -
Available on Iterable<
Pairs of elements of the indices and elements of this iterable.T> , provided by the IterableExtensions extensionno setter - isEmpty → bool
-
Whether this collection has no elements.
no setterinherited
- isNotEmpty → bool
-
Whether this collection has at least one element.
no setterinherited
-
iterator
→ Iterator<
Object?> -
A new
Iteratorthat allows iterating the elements of thisIterable.no setterinherited - last → Object?
-
The last element.
no setterinherited
- lastOrNull → T?
-
Available on Iterable<
The last element of this iterable, orT> , provided by the IterableExtensions extensionnullif the iterable is empty.no setter - length → int
-
The number of elements in this array.
no setterinherited
-
nonNulls
→ Iterable<
T> -
Available on Iterable<
The non-T?> , provided by the NullableIterableExtensions extensionnullelements of this iterable.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- single → Object?
-
Checks that this iterable has only one element, and returns that element.
no setterinherited
- singleOrNull → T?
-
Available on Iterable<
The single element of this iterator, orT> , provided by the IterableExtensions extensionnull.no setter -
wait
→ Future<
List< T> > -
Available on Iterable<
Waits for futures in parallel.Future< , provided by the FutureIterable extensionT> >no setter
Methods
-
any(
bool test(Object? element)) → bool -
Checks whether any element of this iterable satisfies
test.inherited -
array(
int index) → Array? -
Returns the element at the given
indexas an Array.inherited -
asNameMap(
) → Map< String, T> -
Available on Iterable<
Creates a map from the names of enum values to the values.T> , provided by the EnumByName extension -
blob(
int index) → Blob? -
Returns the element at the given
indexas a Blob.inherited -
boolean(
int index) → bool -
Returns the element at the given
indexas a bool.inherited -
byName(
String name) → T -
Available on Iterable<
Finds the enum value in this list with nameT> , provided by the EnumByName extensionname. -
cast<
R> () → Iterable< R> -
A view of this iterable as an iterable of
Rinstances.inherited -
contains(
Object? element) → bool -
Whether the collection contains an element equal to
element.inherited -
date(
int index) → DateTime? -
Returns the element at the given
indexas a DateTime.inherited -
dictionary(
int index) → Dictionary? -
Returns the element at the given
indexas a Dictionary.inherited -
elementAt(
int index) → Object? -
Returns the
indexth element.inherited -
elementAtOrNull(
int index) → T? -
Available on Iterable<
The element at positionT> , provided by the IterableExtensions extensionindexof this iterable, ornull. -
every(
bool test(Object? element)) → bool -
Checks whether every element of this iterable satisfies
test.inherited -
expand<
T> (Iterable< T> toElements(Object? element)) → Iterable<T> -
Expands each element of this Iterable into zero or more elements.
inherited
-
firstWhere(
bool test(Object? element), {Object? orElse()?}) → Object? -
The first element that satisfies the given predicate
test.inherited -
float(
int index) → double -
Returns the element at the given
indexas an floating point number.inherited -
fold<
T> (T initialValue, T combine(T previousValue, Object? element)) → T -
Reduces a collection to a single value by iteratively combining each
element of the collection with an existing value
inherited
-
followedBy(
Iterable< Object?> other) → Iterable<Object?> -
Creates the lazy concatenation of this iterable and
other.inherited -
forEach(
void action(Object? element)) → void -
Invokes
actionon each element of this iterable in iteration order.inherited -
integer(
int index) → int -
Returns the element at the given
indexas an integer number.inherited -
join(
[String separator = ""]) → String -
Converts each element to a String and concatenates the strings.
inherited
-
lastWhere(
bool test(Object? element), {Object? orElse()?}) → Object? -
The last element that satisfies the given predicate
test.inherited -
map<
T> (T toElement(Object? e)) → Iterable< T> -
The current elements of this iterable modified by
toElement.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
number(
int index) → num? -
Returns the element at the given
indexas a num.inherited -
reduce(
Object? combine(Object? value, Object? element)) → Object? -
Reduces a collection to a single value by iteratively combining elements
of the collection using the provided function.
inherited
-
singleWhere(
bool test(Object? element), {Object? orElse()?}) → Object? -
The single element that satisfies
test.inherited -
skip(
int count) → Iterable< Object?> -
Creates an Iterable that provides all but the first
countelements.inherited -
skipWhile(
bool test(Object? value)) → Iterable< Object?> -
Creates an
Iterablethat skips leading elements whiletestis satisfied.inherited -
string(
int index) → String? -
Returns the element at the given
indexas a String.inherited -
take(
int count) → Iterable< Object?> -
Creates a lazy iterable of the
countfirst elements of this iterable.inherited -
takeWhile(
bool test(Object? value)) → Iterable< Object?> -
Creates a lazy iterable of the leading elements satisfying
test.inherited -
toJson(
) → String - Returns this array's data as JSON.
-
toList(
{bool growable = true}) → List< Object?> -
Creates a List containing the elements of this Iterable.
inherited
-
toMutable(
) → MutableArray - Returns a mutable copy of this array.
-
toPlainList(
) → List< Object?> -
Deeply converts this array into a representation of plain Dart objects and
returns it.
inherited
-
toSet(
) → Set< Object?> -
Creates a Set containing the same elements as this iterable.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
value<
T extends Object> (int index) → T? -
Returns the element at the given
index.inherited -
where(
bool test(Object? element)) → Iterable< Object?> -
Creates a new lazy Iterable with all elements that satisfy the
predicate
test.inherited -
whereType<
T> () → Iterable< T> -
Creates a new lazy Iterable with all elements that have type
T.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int index) → Fragment -
Returns a Fragment for the value at the given
index.inherited