anyAndEvery static method
Starts an ANY AND EVERY quantified range predicate and defines a
variable.
An ANY AND EVERY quantified array expression returns true if the array
is NOT empty and at least one of the elements in the array
matches.
Implementation
static ArrayExpressionIn anyAndEvery(VariableExpressionInterface variable) =>
ArrayExpressionInImpl(.anyAndEvery, variable);