float abstract method
Returns the element at the given index as an floating point number.
Returns a default value (integer: 0, double: 0.0, boolean: false) if
the element is not of the expected type or is null.
Throws a RangeError if the index is ouf of range.
Implementation
double float(int index);