listening property
Future<void>
get
listening
Future that completes once the stream is fully subscribe and rejects with an error if subscribing to the stream failed.
Implementation
Future<void> get listening;