AsyncReplicator class abstract interface Replication
A Replicator with a primarily asynchronous API.
- Implemented types
Properties
- config → ReplicatorConfiguration
-
This replicator's configuration.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isClosed → bool
-
Whether this resource has been closed.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serverCertificate
→ Future<
Certificate?> -
The TLS
Certificatereceived when connecting to the server.no setteroverride -
status
→ Future<
ReplicatorStatus> -
Returns this replicator's status.
no setteroverride
Methods
-
addChangeListener(
ReplicatorChangeListener listener) → Future< ListenerToken> -
Adds a
listenerto be notified of changes to the status of this replicator.override -
addDocumentReplicationListener(
DocumentReplicationListener listener) → Future< ListenerToken> -
Adds a
listenerto be notified of DocumentReplications performed by this replicator.override -
changes(
) → AsyncListenStream< ReplicatorChange> -
Returns a Stream to be notified of changes to the status of this
replicator.
override
-
close(
) → Future< void> -
Closes this resource and frees the resources it uses.
inherited
-
documentReplications(
) → AsyncListenStream< DocumentReplication> -
Returns a Stream to be notified of DocumentReplications performed by
this replicator.
override
-
isDocumentPendingInCollection(
String documentId, Collection collection) → Future< bool> -
Returns whether the Document with the given
documentId, in the givencollection, has revisions pending to be pushed.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pendingDocumentIdsInCollection(
Collection collection) → Future< Set< String> > -
Returns a Set of ids for Documents in the given
collection, who have revisions pending to be pushed.override -
removeChangeListener(
ListenerToken token) → Future< void> -
Removes a previously added change listener.
override
-
start(
{bool reset = false}) → Future< void> -
Starts this replicator with an option to
resetthe local checkpoint of the replicator.override -
stop(
) → Future< void> -
Stops this replicator, if running.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
ReplicatorConfiguration config) → Future< AsyncReplicator> -
Creates a replicator for replicating Documents between a local
AsyncDatabase and a target database.
override