AsyncSelect class abstract final Query Builder

Version of Select for building AsyncQuerys.

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
isClosed → bool
Whether this resource has been closed.
no setterinherited
jsonRepresentation → String?
The JSON representation of this query.
no setterinherited
parameters → Parameters?
The values with which to substitute the parameters defined in the query.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sqlRepresentation → String?
The SQL++ representation of this query.
no setterinherited

Methods

addChangeListener(QueryChangeListener<ResultSet> listener) → Future<ListenerToken>
Adds a listener to be notified of changes to the results of this query.
inherited
changes() → AsyncListenStream<QueryChange<ResultSet>>
Returns a Stream to be notified of changes to the results of this query.
inherited
execute() → Future<ResultSet>
Executes this query.
inherited
explain() → Future<String>
Returns a string describing the implementation of the compiled query.
inherited
from(DataSourceInterface dataSource) → AsyncFrom
Creates and returns a FROM clause query component with the given dataSource.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeChangeListener(ListenerToken token) → Future<void>
Removes a previously added change listener.
inherited
setParameters(Parameters? value) → Future<void>
Sets the parameters of this query.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited