AsyncWhere class abstract final Query Builder

Version of Where for building AsyncQuerys.

Implemented types

Properties

hashCode → int
The hash code for this object.
no setterinherited
isClosed → bool
Whether this resource has been closed.
no setterinherited
jsonRepresentation → String?
The JSON representation of this query.
no setterinherited
parameters → Parameters?
The values with which to substitute the parameters defined in the query.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sqlRepresentation → String?
The SQL++ representation of this query.
no setterinherited

Methods

addChangeListener(QueryChangeListener<ResultSet> listener) → Future<ListenerToken>
Adds a listener to be notified of changes to the results of this query.
inherited
changes() → AsyncListenStream<QueryChange<ResultSet>>
Returns a Stream to be notified of changes to the results of this query.
inherited
execute() → Future<ResultSet>
Executes this query.
inherited
explain() → Future<String>
Returns a string describing the implementation of the compiled query.
inherited
groupBy(ExpressionInterface expression0, [ExpressionInterface? expression1, ExpressionInterface? expression2, ExpressionInterface? expression3, ExpressionInterface? expression4, ExpressionInterface? expression5, ExpressionInterface? expression6, ExpressionInterface? expression7, ExpressionInterface? expression8, ExpressionInterface? expression9]) → AsyncGroupBy
Creates and returns a GROUP BY clause query component with the given expressions.
inherited
groupByAll(Iterable<ExpressionInterface> expressions) → AsyncGroupBy
Creates and returns a GROUP BY clause query component with the given expressions.
inherited
limit(ExpressionInterface limit, {ExpressionInterface? offset}) → AsyncLimit
Creates and returns a LIMIT clause query component with the given limit and offset.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
orderBy(OrderingInterface ordering0, [OrderingInterface? ordering1, OrderingInterface? ordering2, OrderingInterface? ordering3, OrderingInterface? ordering4, OrderingInterface? ordering5, OrderingInterface? ordering6, OrderingInterface? ordering7, OrderingInterface? ordering8, OrderingInterface? ordering9]) → AsyncOrderBy
Creates and returns a ORDER BY clause query component with the given orderings.
inherited
orderByAll(Iterable<OrderingInterface> orderings) → AsyncOrderBy
Creates and returns a ORDER BY clause query component with the given orderings.
inherited
removeChangeListener(ListenerToken token) → Future<void>
Removes a previously added change listener.
inherited
setParameters(Parameters? value) → Future<void>
Sets the parameters of this query.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited