Certificate class abstract final Replication Enterprise Edition

A X.509 certificate.

This API is only available in the Enterprise Edition.

Properties

attributes CertificateAttributes
The issuer and Subject Alternative Name (SAN) attributes of this certificate.
no setter
created DateTime
The date when this certificate was created.
no setter
expires DateTime
The date when this certificate expires.
no setter
hashCode int
The hash code for this object.
no setterinherited
publicKey Future<KeyPair>
A KeyPair only containing the public key of this certificate.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDer() DerData
Encodes this certificate as DER data.
toPem() PemData
Encodes this certificate as PEM data.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(CryptoData data) Certificate
Decodes a Certificate from the given data.
decodeMultiple(PemData data) List<Certificate>
Decodes one or more Certificates from the given data.