ClientCertificateAuthenticator class final

An Authenticator that presents a client certificate to the server during the initial SSL/TLS handshake.

This API is only available in the Enterprise Edition.

This is currently only supported for authenticating with an UrlEndpointListener.

See also:

Inheritance

Constructors

ClientCertificateAuthenticator(TlsIdentity identity)
Creates a new ClientCertificateAuthenticator that uses the Certificate and KeyPair of the given identity to authenticate the client to the server.

Properties

hashCode int
The hash code for this object.
no setterinherited
identity TlsIdentity
The TlsIdentity that contains the Certificate and KeyPair to use for authentication with the server.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited