deleteDocument abstract method
FutureOr<bool>
deleteDocument(
- Document document, [
- ConcurrencyControl concurrencyControl = ConcurrencyControl.lastWriteWins
Deletes a document from this collection, resolving conflicts through
ConcurrencyControl.
When write operations are executed concurrently, the last writer will win
by default. In this case the result is always true.
To fail on conflict instead, pass ConcurrencyControl.failOnConflict to
concurrencyControl. In this case, if the document could not be deleted
the result is false. On success it is true.
Implementation
FutureOr<bool> deleteDocument(
Document document, [
ConcurrencyControl concurrencyControl = ConcurrencyControl.lastWriteWins,
]);