copy static method
Copies a canned database from the given path to a new database with the
given name and config.
The new database will be created at the directory specified in the
config.
Implementation
static Future<void> copy({
required String from,
required String name,
DatabaseConfiguration? config,
}) => AsyncDatabase.copy(from: from, name: name, config: config);