deleteCollection abstract method
Deletes the Collection with the given name in the given scope.
Implementation
FutureOr<void> deleteCollection(
String name, [
String scope = Scope.defaultName,
]);
Deletes the Collection with the given name in the given scope.
FutureOr<void> deleteCollection(
String name, [
String scope = Scope.defaultName,
]);