path property
String?
get
path
The path to this database.
Is null if the database is closed or deleted.
Implementation
String? get path;
The path to this database.
Is null if the database is closed or deleted.
String? get path;