DeleteDocumentOp class final Tracing

Operation that deletes a Document from a Collection.

Inheritance
Implemented types

Constructors

DeleteDocumentOp(Collection collection, Document document, ConcurrencyControl concurrencyControl)

Properties

collection → Collection
The collection involved in this operation.
finalinherited
concurrencyControl → ConcurrencyControl
The concurrency control to use.
final
document → Document
The document to delete.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of this operation.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited