float abstract method
Returns the value for the given key as a floating point number.
Returns a default value (integer: 0, double: 0.0, boolean: false) if
the value is not a of the expected typ, is null or does not exist for
the given key.
Implementation
double float(String key);