DocumentChange class final Database

A Document change event.

Annotations
  • @immutable

Constructors

DocumentChange(Database database, Collection collection, String documentId)
Creates a Document change event.
const

Properties

collection → Collection
The collection that contains the changed Document.
final
database → Database
The database that contains the changed Document.
final
documentId → String
The id of the Document that changed.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override