Expression class abstract final Query Builder

Factory for creating expressions when building Querys through the QueryBuilder.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

all() → PropertyExpressionInterface
Creates the * expression.
array(Iterable<Object?>? value) → ExpressionInterface
Creates a literal array expression.
boolean(bool value) → ExpressionInterface
Creates a literal bool expression.
date(DateTime? value) → ExpressionInterface
Creates a literal DateTime expression.
dictionary(Map<String, Object?>? value) → ExpressionInterface
Creates a literal dictionary expression.
float(double value) → ExpressionInterface
Creates a literal floating point number expression.
integer(int value) → ExpressionInterface
Creates a literal integer number expression.
negated(ExpressionInterface expression) → ExpressionInterface
Creates an expression negating the given expression.
not(ExpressionInterface expression) → ExpressionInterface
Creates an expression negating the given expression.
number(num? value) → ExpressionInterface
Creates a literal num expression.
parameter(String name) → ExpressionInterface
Creates a parameter expression with the given name.
property(String propertyPath) → PropertyExpressionInterface
Creates a property expression representing the value at the given propertyPath.
string(String? value) → ExpressionInterface
Creates a literal String expression.
value(Object? value) → ExpressionInterface
Creates a literal value expression.