or abstract method
Returns a new expression which performs a logical OR of this expression
and the given expression.
Implementation
ExpressionInterface or(ExpressionInterface expression);
Returns a new expression which performs a logical OR of this expression
and the given expression.
ExpressionInterface or(ExpressionInterface expression);