regex abstract method
Returns a new expression which evaluates whether this expression regex
matches the the given expression.
Implementation
ExpressionInterface regex(ExpressionInterface expression);
Returns a new expression which evaluates whether this expression regex
matches the the given expression.
ExpressionInterface regex(ExpressionInterface expression);