FullTextIndex class abstract final Query

A full-text search index for full-text search queries with the MATCH operator.

Implemented types

Constructors

FullTextIndex(Iterable<FullTextIndexItem> items)
Creates a full text index from the FullTextIndexItems to index.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

ignoreAccents(bool ignoreAccents) → FullTextIndex
Specifies whether the index ignores accents and diacritical marks.
langauge(FullTextLanguage language) → FullTextIndex
Specifies the dominant language of the index.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited