ignoreAccents property
Whether the index should ignore accents and diacritical marks.
The default is false.
Implementation
abstract bool ignoreAccents;
Whether the index should ignore accents and diacritical marks.
The default is false.
abstract bool ignoreAccents;