Join class abstract final Query Builder
Factory for creating JOIN clauses.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
crossJoin(
DataSourceInterface dataSource) → JoinInterface -
Creates an
CROSS JOINwith the givendataSource. -
innerJoin(
DataSourceInterface dataSource) → JoinOnInterface -
Creates an
INNER JOINwith the givendataSource. -
join(
DataSourceInterface dataSource) → JoinOnInterface -
Creates a
JOINwith the givendataSource. -
leftJoin(
DataSourceInterface dataSource) → JoinOnInterface -
Creates a
LEFT JOINwith the givendataSource. -
leftOuterJoin(
DataSourceInterface dataSource) → JoinOnInterface -
Creates a
LEFT OUTER JOINwith the givendataSource.