ListenerCertificateAuthenticator class final Replication Enterprise Edition

A certificate-based ListenerAuthenticator for a UrlEndpointListener.

This API is only available in the Enterprise Edition.

See also:

Implemented types

Constructors

ListenerCertificateAuthenticator(ListenerCertificateAuthenticatorFunction handler)
Creates a new ListenerCertificateAuthenticator that uses the given handler to authenticate clients.
factory
ListenerCertificateAuthenticator.fromRoots(List<Certificate> certificates)
Creates a new ListenerCertificateAuthenticator that trusts the given root certificates when authenticating clients.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited