ListenerPasswordAuthenticator class final Replication Enterprise Edition

A password-based ListenerAuthenticator for a UrlEndpointListener.

This API is only available in the Enterprise Edition.

Implemented types

Constructors

ListenerPasswordAuthenticator(ListenerPasswordAuthenticatorFunction handler)
Creates a new ListenerPasswordAuthenticator that uses the given handler to authenticate clients.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited