LogMessage class final Logging

A log message.

Constructors

LogMessage(LogLevel level, LogDomain domain, String message)
Creates a log message.

Properties

domain → LogDomain
The sub system which emitted this message.
final
hashCode → int
The hash code for this object.
no setterinherited
level → LogLevel
The importance of this log message.
final
message → String
The log message.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited