Provides access to array data.
- Implemented types
- Available extensions
Constructors
-
MutableArray([Iterable<
Object?> ? data]) -
Creates a MutableArray, optionally initialized with
data.factory
Properties
- first → Object?
-
The first element.
no setterinherited
- firstOrNull → T?
-
Available on Iterable<
The first element of this iterator, orT> , provided by the IterableExtensions extensionnullif the iterable is empty.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
indexed
→ Iterable<
(int, T)> -
Available on Iterable<
Pairs of elements of the indices and elements of this iterable.T> , provided by the IterableExtensions extensionno setter - isEmpty → bool
-
Whether this collection has no elements.
no setterinherited
- isNotEmpty → bool
-
Whether this collection has at least one element.
no setterinherited
-
iterator
→ Iterator<
Object?> -
A new
Iteratorthat allows iterating the elements of thisIterable.no setterinherited - last → Object?
-
The last element.
no setterinherited
- lastOrNull → T?
-
Available on Iterable<
The last element of this iterable, orT> , provided by the IterableExtensions extensionnullif the iterable is empty.no setter - length → int
-
The number of elements in this array.
no setterinherited
-
nonNulls
→ Iterable<
T> -
Available on Iterable<
The non-T?> , provided by the NullableIterableExtensions extensionnullelements of this iterable.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- single → Object?
-
Checks that this iterable has only one element, and returns that element.
no setterinherited
- singleOrNull → T?
-
Available on Iterable<
The single element of this iterator, orT> , provided by the IterableExtensions extensionnull.no setter -
wait
→ Future<
List< T> > -
Available on Iterable<
Waits for futures in parallel.Future< , provided by the FutureIterable extensionT> >no setter
Methods
-
addArray(
Array? value) → void -
Adds an Array at the end of this array.
inherited
-
addBlob(
Blob? value) → void -
Adds a Blob at the end of this array.
inherited
-
addBoolean(
bool value) → void -
Adds a bool at the end of this array.
inherited
-
addDate(
DateTime? value) → void -
Adds a DateTime at the end of this array.
inherited
-
addDictionary(
Dictionary? value) → void -
Adds a Dictionary at the end of this array.
inherited
-
addFloat(
double value) → void -
Adds a floating point number at the end of this array.
inherited
-
addInteger(
int value) → void -
Adds a integer number at the end of this array.
inherited
-
addNumber(
num? value) → void -
Adds a num at the end of this array.
inherited
-
addString(
String? value) → void -
Adds a String at the end of this array.
inherited
-
addValue(
Object? value) → void -
Adds a
valueat the end of this array.inherited -
any(
bool test(Object? element)) → bool -
Checks whether any element of this iterable satisfies
test.inherited -
array(
int index) → MutableArray? -
Returns the element at the given
indexas a MutableArray.inherited -
asNameMap(
) → Map< String, T> -
Available on Iterable<
Creates a map from the names of enum values to the values.T> , provided by the EnumByName extension -
blob(
int index) → Blob? -
Returns the element at the given
indexas a Blob.inherited -
boolean(
int index) → bool -
Returns the element at the given
indexas a bool.inherited -
byName(
String name) → T -
Available on Iterable<
Finds the enum value in this list with nameT> , provided by the EnumByName extensionname. -
cast<
R> () → Iterable< R> -
A view of this iterable as an iterable of
Rinstances.inherited -
contains(
Object? element) → bool -
Whether the collection contains an element equal to
element.inherited -
date(
int index) → DateTime? -
Returns the element at the given
indexas a DateTime.inherited -
dictionary(
int index) → MutableDictionary? -
Returns the element at the given
indexas a MutableDictionary.inherited -
elementAt(
int index) → Object? -
Returns the
indexth element.inherited -
elementAtOrNull(
int index) → T? -
Available on Iterable<
The element at positionT> , provided by the IterableExtensions extensionindexof this iterable, ornull. -
every(
bool test(Object? element)) → bool -
Checks whether every element of this iterable satisfies
test.inherited -
expand<
T> (Iterable< T> toElements(Object? element)) → Iterable<T> -
Expands each element of this Iterable into zero or more elements.
inherited
-
firstWhere(
bool test(Object? element), {Object? orElse()?}) → Object? -
The first element that satisfies the given predicate
test.inherited -
float(
int index) → double -
Returns the element at the given
indexas an floating point number.inherited -
fold<
T> (T initialValue, T combine(T previousValue, Object? element)) → T -
Reduces a collection to a single value by iteratively combining each
element of the collection with an existing value
inherited
-
followedBy(
Iterable< Object?> other) → Iterable<Object?> -
Creates the lazy concatenation of this iterable and
other.inherited -
forEach(
void action(Object? element)) → void -
Invokes
actionon each element of this iterable in iteration order.inherited -
insertArray(
Array? value, {required int at}) → void -
Inserts an Array
atthe given index.inherited -
insertBlob(
Blob? value, {required int at}) → void -
Inserts a Blob
atthe given index.inherited -
insertBoolean(
bool value, {required int at}) → void -
Inserts a bool
atthe given index.inherited -
insertDate(
DateTime? value, {required int at}) → void -
Inserts a DateTime
atthe given index.inherited -
insertDictionary(
Dictionary? value, {required int at}) → void -
Inserts a Dictionary
atthe given index.inherited -
insertFloat(
double value, {required int at}) → void -
Inserts a floating point number
atthe given index.inherited -
insertInteger(
int value, {required int at}) → void -
Inserts an integer number
atthe given index.inherited -
insertNumber(
num? value, {required int at}) → void -
Inserts a num
atthe given index.inherited -
insertString(
String? value, {required int at}) → void -
Inserts a String
atthe given index.inherited -
insertValue(
Object? value, {required int at}) → void -
Inserts a
valueatthe given index.inherited -
integer(
int index) → int -
Returns the element at the given
indexas an integer number.inherited -
join(
[String separator = ""]) → String -
Converts each element to a String and concatenates the strings.
inherited
-
lastWhere(
bool test(Object? element), {Object? orElse()?}) → Object? -
The last element that satisfies the given predicate
test.inherited -
map<
T> (T toElement(Object? e)) → Iterable< T> -
The current elements of this iterable modified by
toElement.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
number(
int index) → num? -
Returns the element at the given
indexas a num.inherited -
reduce(
Object? combine(Object? value, Object? element)) → Object? -
Reduces a collection to a single value by iteratively combining elements
of the collection using the provided function.
inherited
-
removeValue(
int index) → void -
Removes the value at the given
index.inherited -
setArray(
Array? value, {required int at}) → void -
Sets an Array
atthe given index.inherited -
setBlob(
Blob? value, {required int at}) → void -
Sets a Blob
atthe given index.inherited -
setBoolean(
bool value, {required int at}) → void -
Sets a bool
atthe given index.inherited -
setData(
Iterable< Object?> data) → void -
Replaces the elements of this array with those of the given Iterable.
inherited
-
setDate(
DateTime? value, {required int at}) → void -
Sets a DateTime
atthe given index.inherited -
setDictionary(
Dictionary? value, {required int at}) → void -
Sets a Dictionary
atthe given index.inherited -
setFloat(
double value, {required int at}) → void -
Sets a floating point number
atthe given index.inherited -
setInteger(
int value, {required int at}) → void -
Sets an integer number
atthe given index.inherited -
setNumber(
num? value, {required int at}) → void -
Sets a num
atthe given index.inherited -
setString(
String? value, {required int at}) → void -
Sets a String
atthe given index.inherited -
setValue(
Object? value, {required int at}) → void -
Sets a
valueatthe given index.inherited -
singleWhere(
bool test(Object? element), {Object? orElse()?}) → Object? -
The single element that satisfies
test.inherited -
skip(
int count) → Iterable< Object?> -
Creates an Iterable that provides all but the first
countelements.inherited -
skipWhile(
bool test(Object? value)) → Iterable< Object?> -
Creates an
Iterablethat skips leading elements whiletestis satisfied.inherited -
string(
int index) → String? -
Returns the element at the given
indexas a String.inherited -
take(
int count) → Iterable< Object?> -
Creates a lazy iterable of the
countfirst elements of this iterable.inherited -
takeWhile(
bool test(Object? value)) → Iterable< Object?> -
Creates a lazy iterable of the leading elements satisfying
test.inherited -
toJson(
) → String -
Returns this array's data as JSON.
inherited
-
toList(
{bool growable = true}) → List< Object?> -
Creates a List containing the elements of this Iterable.
inherited
-
toMutable(
) → MutableArray -
Returns a mutable copy of this array.
inherited
-
toPlainList(
) → List< Object?> -
Deeply converts this array into a representation of plain Dart objects and
returns it.
inherited
-
toSet(
) → Set< Object?> -
Creates a Set containing the same elements as this iterable.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
value<
T extends Object> (int index) → T? -
Returns the element at the given
index.inherited -
where(
bool test(Object? element)) → Iterable< Object?> -
Creates a new lazy Iterable with all elements that satisfy the
predicate
test.inherited -
whereType<
T> () → Iterable< T> -
Creates a new lazy Iterable with all elements that have type
T.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int index) → MutableFragment -
Returns a MutableFragment for the value at the given
index.inherited