OID class Replication

An object identifier (OID) for use in X.509 Certificates.

Annotations
  • @immutable

Constructors

OID(List<int> arcs)
Creates an OID from a list of arcs.
OID.parse(String oid)
Parses a string representation of an OID, e.g. 1.2.840.113549.
factory

Properties

arcs List<int>
The arcs of this OID, e.g. 1.2.840.113549, represented as a list of integers.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override