PemData class final Replication

PEM-encoded cryptographic data.

PEM data can contain multiple objects in multiple blocks.

Implemented types
Annotations
  • @immutable

Constructors

PemData(String data)
Creates a new instance of PemData with the given PEM data.
const
PemData.combined(Iterable<PemData> blocks)
Creates a new instance of PemData by concatenating the given blocks of PEM data.
factory

Properties

blocks List<PemData>
The individual PEM blocks contained in this data.
no setter
data String
The PEM data as a string.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override