predict abstract method

Dictionary? predict(
  1. Dictionary input
)

Invokes the model with the given input dictionary and returns the prediction result.

The input dictionary corresponds to the input parameter of the query builder Function_.prediction function or the SQL++ PREDICTION function.

If the model cannot return a result, the prediction callback should return null, which will be evaluated as MISSING.

If the model throws an exception, the exception will be caught and logged and the prediction will be evaluated as MISSING.

Implementation

Dictionary? predict(Dictionary input);