jsonRepresentation property
String?
get
jsonRepresentation
The JSON representation of this query.
This value can be used to recreate this query with Database.createQuery
and the parameter json set to true.
Is null, if this query was created from an SQL++ query.
Implementation
String? get jsonRepresentation;