sqlRepresentation property
String?
get
sqlRepresentation
The SQL++ representation of this query.
This value can be used to recreate this query with Database.createQuery.
Is null, if this query was created through the builder API or from the
JSON representation.
Implementation
String? get sqlRepresentation;