SelectResult class abstract final Query Builder

Factory for select results.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

all() → SelectResultFrom
Creates a select result that returns all document properties.
expression(ExpressionInterface expression) → SelectResultAs
Creates a select result from the given expression.
property(String propertyPath) → SelectResultAs
Creates a select result from the given propertyPath.