SyncQuery class abstract interface Query

A Query with a primarily synchronous API.

Implemented types
Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
isClosed → bool
Whether this resource has been closed.
no setterinherited
jsonRepresentation → String?
The JSON representation of this query.
no setterinherited
parameters → Parameters?
The values with which to substitute the parameters defined in the query.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sqlRepresentation → String?
The SQL++ representation of this query.
no setterinherited

Methods

addChangeListener(QueryChangeListener<SyncResultSet> listener) → ListenerToken
Adds a listener to be notified of changes to the results of this query.
override
changes() → Stream<QueryChange<SyncResultSet>>
Returns a Stream to be notified of changes to the results of this query.
override
execute() → SyncResultSet
Executes this query.
override
explain() → String
Returns a string describing the implementation of the compiled query.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeChangeListener(ListenerToken token) → void
Removes a previously added change listener.
override
setParameters(Parameters? value) → void
Sets the parameters of this query.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited