SyncWhereRouter class abstract interface Query Builder
Version of WhereRouter for building SyncQuerys.
- Implemented types
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
where(
ExpressionInterface expression) → SyncWhere -
Creates and returns a
WHEREclause query component with the givenexpression.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited