TlsIdentity class abstract Replication Enterprise Edition

TLS identity including a KeyPair and X.509 Certificate chain used for configuring TLS communication for replication.

This API is only available in the Enterprise Edition.

Constructors

TlsIdentity.from({required KeyPair keyPair, required List<Certificate> certificates})
Creates a TlsIdentity from an existing identity using the provided RSA keyPair and chain of certificates.
factory

Properties

certificates List<Certificate>
The chain of X.509 Certificates associated with this identity.
no setter
expires DateTime
The expiration date of the first Certificate in the chain associated with this identity.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createIdentity({required Set<KeyUsage> keyUsages, required CertificateAttributes attributes, required DateTime expiration, String? label, KeyPair? keyPair}) Future<TlsIdentity>
Creates a self-signed TlsIdentity.
deleteIdentity(String label) Future<void>
Deletes a persisted identity with the given label.
identity(String label) Future<TlsIdentity?>
Retrieves a persisted identity with the given label.
identityWithCertificates(List<Certificate> certificates) Future<TlsIdentity>
Retrieves an identity associated with the provided chain of certificates from the platform's secure storage.