identityWithCertificates static method

Future<TlsIdentity> identityWithCertificates(
  1. List<Certificate> certificates
)

Retrieves an identity associated with the provided chain of certificates from the platform's secure storage.

The KeyPair will be looked up by the first Certificate in the chain.

Persisted identities are not supported on Android or Linux.

Implementation

static Future<TlsIdentity> identityWithCertificates(
  List<Certificate> certificates,
) => FfiTlsIdentity.identityWithCertificates(certificates.cast());