TypedMutableDocumentObject<D extends TypedDocumentObject<Object> , MD extends TypedDocumentObject<Object> > class
abstract
interface
Typed Data
The type that is implemented by all typed mutable documents.
All typed mutable documents have an immutable supertype that has the type
D. MD is the self type of the mutable subtype.
- Inheritance
-
- Object
- TypedDocumentObject<
MD> - TypedMutableDocumentObject
- Implemented types
-
- TypedMutableDictionaryObject<
D, MD>
- TypedMutableDictionaryObject<
- Annotations
-
- @experimental
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMutable(
) → MD -
Returns a mutable copy of this object.
inherited
-
toString(
{String? indent}) → String -
Returns a string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited