value property
The value that the dictionary or document must contain at path to match.
If this is null, the name of the class annotated with TypedDictionary
or TypedDocument is used.
Implementation
final String? value;
The value that the dictionary or document must contain at path to match.
If this is null, the name of the class annotated with TypedDictionary
or TypedDocument is used.
final String? value;