ConnectionStatus class final Replication Enterprise Edition
The connection status of an UrlEndpointListener.
This API is only available in the Enterprise Edition.
Constructors
- ConnectionStatus({required int connectionCount, required int activeConnectionCount})
- Creates a new ConnectionStatus with the specified parameters.
Properties
- activeConnectionCount → int
-
The number of clients currently replicating with the listener.
final
- connectionCount → int
-
The number of clients currently connected to the listener.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited