dictionary abstract method
Returns the value for the given key as a MutableDictionary.
Returns null if a value for the given key does not exist, is not of
the expected type or it is null.
Implementation
@override
MutableDictionary? dictionary(String key);