Prediction class abstract final Query Enterprise Edition
Manager for registering and unregistering PredictiveModels.
This API is only available in the Enterprise Edition.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerModel(
String name, PredictiveModel model) → void -
Registers a PredictiveModel by the given
name. -
toString(
) → String -
A string representation of this object.
inherited
-
unregisterModel(
String name) → void -
Unregisters the PredictiveModel with the given
name.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited