ReplicatorConfiguration class final Replication
Configuration for a Replicator.
Constructors
-
ReplicatorConfiguration({required Endpoint target, ReplicatorType replicatorType = ReplicatorType.pushAndPull, bool continuous = false, Authenticator? authenticator, bool acceptOnlySelfSignedServerCertificate = false, CryptoData? pinnedServerCertificate, PemData? trustedRootCertificates, Map<
String, String> ? headers, bool enableAutoPurge = true, bool acceptParentDomainCookies = false, Duration? heartbeat, int? maxAttempts, Duration? maxAttemptWaitTime}) - Creates a configuration for a Replicator.
- ReplicatorConfiguration.from(ReplicatorConfiguration config)
-
Creates a configuration for a Replicator from another
configby copying it.
Properties
- acceptOnlySelfSignedServerCertificate ↔ bool
-
Whether the replicator accepts any and only self-signed certificates.
getter/setter pair
- acceptParentDomainCookies ↔ bool
-
Whether to remove the restriction that does not allow the replicator to
save the parent-domain cookies from the HTTP response.
getter/setter pair
- authenticator ↔ Authenticator?
-
The Authenticator to authenticate with a remote target.
getter/setter pair
- continuous ↔ bool
-
The continuous flag indicating whether the replicator should stay active
indefinitely to replicate changed documents.
getter/setter pair
- enableAutoPurge ↔ bool
-
Whether to automatically purge a document when the user looses access to
it, on the server.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
↔ Map<
String, String> ? -
Extra HTTP headers to send in all requests to the remote target.
getter/setter pair
- heartbeat ↔ Duration?
-
The heartbeat interval.
getter/setter pair
- maxAttempts ↔ int?
-
The maximum attempts to connect.
getter/setter pair
- maxAttemptWaitTime ↔ Duration?
-
Max wait time between attempts.
getter/setter pair
- pinnedServerCertificate ↔ CryptoData?
-
The remote target's SSL certificate.
getter/setter pair
- replicatorType ↔ ReplicatorType
-
Replicator type indication the direction of the replicator.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target → Endpoint
-
The replication target to replicate with.
final
- trustedRootCertificates ↔ PemData?
-
A set of trusted root certificates to use for verifying the SSL
certificate of the remote target.
getter/setter pair
Methods
-
addCollection(
Collection collection, [CollectionConfiguration? config]) → void - Configures a Collection for replication.
-
addCollections(
Iterable< Collection> collections, [CollectionConfiguration? config]) → void - Configures multiple Collections for replication.
-
collectionConfiguration(
Collection collection) → CollectionConfiguration? - Returns the CollectionConfiguration for a Collection in this configuration.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeCollection(
Collection collection) → void - Removes the CollectionConfiguration for a Collection from this configuration.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited